# Time

A time object represents a (local) time of day, independent of any particular day

URI: http://www.w3.org/2001/XMLSchema#dateTime

* [base](https://w3id.org/linkml/base): XSDTime


* [repr](https://w3id.org/linkml/repr): str




## Identifier and Mapping Information


